@@ -7,9 +7,8 @@
 #
 # Licensed under the MIT/Expat License.
 
-# imports
-import sys
 import re
+import sys
 
 
 class LinesHandler:
@@ -18,7 +17,7 @@ class LinesHandler:
         self.content = content
         self.line_num = 0
 
-    def _find_indexes(self, myregex, too_many_msg, not_at_start_msg):
+    def _find_indices(self, myregex, too_many_msg, not_at_start_msg):
         idxs = [x for x in range(self.line_num, len(self.content))
                 if re.match(myregex, self.content[x])]
 
@@ -36,7 +35,7 @@ class LinesHandler:
     def _extract_optional_line_from_start(self, validregex, wrong_fmt_msg,
                                           myregex, too_many_msg,
                                           not_at_start_msg):
-        i = self._find_indexes(myregex, too_many_msg, not_at_start_msg)
+        i = self._find_indices(myregex, too_many_msg, not_at_start_msg)
         if i == self.line_num:
             line = self.content[self.line_num]
             if not re.match(validregex, line):
@@ -47,38 +46,42 @@ class LinesHandler:
             return None
 
 
-def shlomif_main(args):
+def cmd_line_main(args):
     output_to_stdout = True
     output_fn = None
-    while args[1][0] == '-':
-        if (args[1] == "-o"):
-            args.pop(0)
-            if not len(args):
+    while len(args) >= 2 and args[1][0] == '-':
+        if args[1] == "-o":
+            args.pop(1)
+            if len(args) < 2:
                 raise ValueError("-o must accept an argument.")
             output_fn = args[1]
             output_to_stdout = False
-            args.pop(0)
-        elif (args[1] == '-'):
+            args.pop(1)
+        elif args[1] == '-':
             break
         else:
             raise ValueError("Unknown flag " + args[1] + "!")
 
     input_from_stdin = True
     input_fn = None
-    if (len(args) >= 2):
-        if (args[1] != "-"):
+    if len(args) >= 2:
+        if args[1] != "-":
             input_fn = args[1]
             input_from_stdin = False
-            args.pop(0)
+        args.pop(1)
+    if len(args) > 1:
+        raise ValueError(
+            "Too many command line arguments starting at '{}'!".format(
+                args[1]))
 
     content = []
     if input_from_stdin:
         content = sys.stdin.readlines()
     else:
-        with open(input_fn) as f:
+        with open(input_fn, "rt") as f:
             content = f.readlines()
 
-    layout = [[None for x in range(0, 52)] for line in range(0, 52)]
+    layout = [[None for x in range(52)] for line in range(52)]
 
     rank_re = r'[A23456789TJQK]'
     suit_re = r'[HCDS]'
@@ -131,18 +134,18 @@ def shlomif_main(args):
             pos += 1
         h.line_num += 1
 
-    for idx in range(0, max_col + 1):
+    for idx in range(max_col + 1):
         line = layout[idx]
         while not line[-1]:
             line.pop()
-        for x in range(0, len(line)):
+        for x in range(len(line)):
             if not line[x]:
                 raise ValueError(
                     "Stack no. %d contains a gap at position no. %d. Aborting."
                     % (idx+1, x+1)
                 )
 
-    with (sys.stdout if output_to_stdout else open(output_fn)) as f:
+    with (sys.stdout if output_to_stdout else open(output_fn, "wt")) as f:
         def _out_line(line):
             if line:
                 f.write(line + "\n")
@@ -156,4 +159,4 @@ def shlomif_main(args):
 
 
 if __name__ == "__main__":
-    sys.exit(shlomif_main(sys.argv))
+    sys.exit(cmd_line_main(sys.argv))
