@@ -13,11 +13,8 @@
 extern "C" {
 #endif
 
+#ifndef FCS_DBM_SINGLE_THREAD
 #include <pthread.h>
-
-// Define FCS_DBM_SINGLE_THREAD to have single thread-per-instance traversal.
-#if 0
-#define FCS_DBM_SINGLE_THREAD 1
 #endif
 
 #include "freecell-solver/fcs_conf.h"
@@ -26,7 +23,6 @@ extern "C" {
 #include "lock.h"
 #include "dbm_calc_derived.h"
 #include "delta_states_any.h"
-#include "dbm_common.h"
 #include "dbm_solver.h"
 #include "dbm_cache.h"
 
