@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // rand.h - header for the Freecell Solver pseudo-random number generator.
 #pragma once
 
@@ -14,14 +12,14 @@
 extern "C" {
 #endif
 
-#include "rinutils.h"
+#include "rinutils/rinutils.h"
 
 typedef long fcs_rand_gen;
 
 static inline void fc_solve_rand_init(
-    fcs_rand_gen *const my_rand, const unsigned int seed)
+    fcs_rand_gen *const my_rand, const fcs_rand_gen seed)
 {
-    *my_rand = (long)seed;
+    *my_rand = seed;
 }
 
 static inline int fc_solve_rand_rand15(fcs_rand_gen *const my_rand)
