@@ -1,19 +1,17 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 #pragma once
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include "fcs_conf.h"
-#include "rinutils.h"
+#include "freecell-solver/fcs_conf.h"
+#include "rinutils/rinutils.h"
 
 #ifdef CARD_DEBUG_PRES
 #define CARD_ZERO() "*"
