@@ -20,7 +20,8 @@
 #include "print_time.h"
 
 static inline int range_solvers_main(int argc, char *argv[], int arg,
-    long long start_board, long long end_board, const long long stop_at)
+    fc_solve_ms_deal_idx_type start_board, fc_solve_ms_deal_idx_type end_board,
+    const fc_solve_ms_deal_idx_type stop_at)
 {
     fcs_iters_int total_num_iters = 0;
 #ifndef FCS_WITHOUT_MAX_NUM_STATES
@@ -76,10 +77,12 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
     }
 #endif
 
-    for (long long board_num = start_board; board_num <= end_board; ++board_num)
+    fcs_state_string state_string;
+    get_board__setup_string(state_string);
+    for (fc_solve_ms_deal_idx_type board_num = start_board;
+         board_num <= end_board; ++board_num)
     {
-        fcs_state_string state_string;
-        get_board((unsigned long long)board_num, state_string);
+        get_board_l__without_setup(board_num, state_string);
 
         const int ret =
             freecell_solver_user_solve_board(instance, state_string);
@@ -102,7 +105,7 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
 
         case FCS_STATE_WAS_SOLVED:
 #ifdef FCS_RANGE_SOLVERS_PRINT_SOLVED
-            printf("Solved Board No. " RIN_LL_FMT "\n", board_num);
+            printf("Solved Board No. " RIN_ULL_FMT "\n", board_num);
 #endif
             print_int(&binary_output,
                 (int)freecell_solver_user_get_num_times_long(instance));
@@ -112,9 +115,16 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
             exit_error("%s", "Unknown ret code!");
         }
 
+#ifndef WIN32
+// #define RIN_ULL6_FMT "%.6llu"
+#define RIN_ULL9_FMT "%09llu"
+#else
+// #define RIN_ULL6_FMT "%.6I64u"
+#define RIN_ULL9_FMT "%09I64u"
+#endif
         if (solutions_directory)
         {
-            sprintf(solution_fn, "%s" RIN_LL9_FMT ".sol", solutions_directory,
+            sprintf(solution_fn, "%s" RIN_ULL9_FMT ".sol", solutions_directory,
                 board_num);
             FILE *const output_fh = fopen(solution_fn, "wt");
             if (!output_fh)
