@@ -28,11 +28,14 @@ extern "C" {
 #include "internal_move_struct.h"
 #include "indirect_buffer.h"
 
-#if MAX_NUM_INITIAL_CARDS_IN_A_STACK + 12 > (MAX_NUM_DECKS * 52)
-#define MAX_NUM_CARDS_IN_A_STACK (MAX_NUM_DECKS * 52)
+#define FCS_MAX_NUM_STACK_CARDS1 (MAX_NUM_INITIAL_CARDS_IN_A_STACK + 12)
+#define FCS_MAX_NUM_STACK_CARDS2 (MAX_NUM_DECKS * 52)
+#if FCS_MAX_NUM_STACK_CARDS1 > FCS_MAX_NUM_STACK_CARDS2
+#define MAX_NUM_CARDS_IN_A_STACK FCS_MAX_NUM_STACK_CARDS2
 #else
-#define MAX_NUM_CARDS_IN_A_STACK (MAX_NUM_INITIAL_CARDS_IN_A_STACK + 12)
+#define MAX_NUM_CARDS_IN_A_STACK FCS_MAX_NUM_STACK_CARDS1
 #endif
+#define FCS_CARDS_COL_WIDTH (MAX_NUM_CARDS_IN_A_STACK + 1)
 
 #ifndef FCS_MAX_NUM_SCANS_BUCKETS
 #define FCS_MAX_NUM_SCANS_BUCKETS 4
@@ -54,40 +57,33 @@ typedef const fcs_card *fcs_const_cards_column;
 typedef fcs_card fcs_state_foundation;
 
 #ifdef COMPACT_STATES
-/*
- * Card:
- * Bits 0-3 - Card Number
- * Bits 4-5 - Suit
- *
- */
-
+// Card:
+// Bits 0-3 - Card Number
+// Bits 4-5 - Suit
 typedef struct
 {
-    fcs_card data[MAX_NUM_STACKS * (MAX_NUM_CARDS_IN_A_STACK + 1) +
-                  MAX_NUM_FREECELLS + 4 * MAX_NUM_DECKS];
+    fcs_card data[MAX_NUM_STACKS * FCS_CARDS_COL_WIDTH + MAX_NUM_FREECELLS +
+                  4 * MAX_NUM_DECKS];
 } fcs_state;
 
-/*
- * Stack: 0 - Number of cards
- *        1-19 - Cards
- * Stacks: stack_num*20 where stack_num >= 0 and
- *         stack_num <= (MAX_NUM_STACKS-1)
- * Bytes: (MAX_NUM_STACKS*20) to
- *      (MAX_NUM_STACKS*20+MAX_NUM_FREECELLS-1)
- *      are Freecells.
- * Bytes: (MAX_NUM_STACKS*20+MAX_NUM_FREECELLS) to
- *      MAX_NUM_STACKS*20+MAX_NUM_FREECELLS+3
- *      are Foundations.
- * */
-
+// Stack: 0 - Number of cards
+//        1-19 - Cards
+// Stacks: stack_num*20 where stack_num >= 0 and
+//         stack_num <= (MAX_NUM_STACKS-1)
+// Bytes: (MAX_NUM_STACKS*20) to
+//      (MAX_NUM_STACKS*20+MAX_NUM_FREECELLS-1)
+//      are Freecells.
+// Bytes: (MAX_NUM_STACKS*20+MAX_NUM_FREECELLS) to
+//      MAX_NUM_STACKS*20+MAX_NUM_FREECELLS+3
+//      are Foundations.
 typedef char fcs_locs_type;
 
 #define fcs_state_get_col(state, col_idx)                                      \
-    ((state).data + ((col_idx) * (MAX_NUM_CARDS_IN_A_STACK + 1)))
+    ((state).data + ((col_idx)*FCS_CARDS_COL_WIDTH))
 #define fcs_freecell_card(state, f)                                            \
-    ((state).data[(MAX_NUM_STACKS * (MAX_NUM_CARDS_IN_A_STACK + 1)) + (f)])
+    ((state).data[(MAX_NUM_STACKS * FCS_CARDS_COL_WIDTH) + (f)])
 #define fcs_foundation_value(state, d)                                         \
-    ((state).data[((MAX_NUM_STACKS * (MAX_NUM_CARDS_IN_A_STACK + 1)) +         \
+    ((state).data[((MAX_NUM_STACKS * FCS_CARDS_COL_WIDTH) +                    \
                       MAX_NUM_FREECELLS) +                                     \
                   (d)])
 
@@ -128,9 +124,7 @@ typedef uint8_t fcs_locs_type;
 
 #else
 #error Neither COMPACT_STATES nor INDIRECT_STACK_STATES are defined.
-#endif /* #if defined COMPACT_STATES -                                         \
-          #elif defined INDIRECT_STACK_STATES                                  \
-        */
+#endif
 
 // These are macros or functions that are common to all the _STATES types.
 #define fcs_increment_foundation(state, foundation_idx)                        \
@@ -202,17 +196,12 @@ static inline bool fcs_col_is_king(
 
 struct fcs_state_keyval_pair_struct;
 
-/*
- * NOTE: the order of elements here is intended to reduce framgmentation
- * and memory consumption. Namely:
- *
- * 1. Pointers come first.
- *
- * 2. ints (32-bit on most platform) come next.
- *
- * 3. chars come next.
- *
- * */
+// NOTE: the order of elements here is intended to reduce framgmentation
+// and memory consumption. Namely:
+//
+// 1. Pointers come first.
+// 2. ints (32-bit on most platform) come next.
+// 3. chars come next.
 struct fcs_state_extra_info_struct
 {
 #ifdef FCS_RCS_STATES
@@ -224,67 +213,55 @@ struct fcs_state_extra_info_struct
     fcs_move_stack *moves_to_parent;
 #endif
 
-#ifndef FCS_WITHOUT_DEPTH_FIELD
+#ifdef FCS_WITH_DEPTH_FIELD
     int depth;
 #endif
 
 #ifndef FCS_WITHOUT_VISITED_ITER
-    /*
-     * The iteration in which this state was marked as visited
-     * */
+    // The iteration in which this state was marked as visited
     fcs_iters_int visited_iter;
 #endif
 
-    /*
-     * This is the number of direct children of this state which were not
-     * yet declared as dead ends. Once this counter reaches zero, this
-     * state too is declared as a dead end.
-     *
-     * It was converted to an unsigned short , because it is extremely
-     * unlikely that a state will have more than 64K active children.
-     * */
+    // This is the number of direct children of this state which were not
+    // yet declared as dead ends. Once this counter reaches zero, this
+    // state too is declared as a dead end.
+    //
+    // It was converted to an unsigned short , because it is extremely
+    // unlikely that a state will have more than 64K active children.
     unsigned short num_active_children;
 
-    /*
-     * This field contains global, scan-independant flags, which are used
-     * from the FCS_VISITED_* enum below.
-     *
-     * FCS_VISITED_IN_SOLUTION_PATH - indicates that the state is in the
-     * solution path found by the scan. (used by the optimization scan)
-     *
-     * FCS_VISITED_IN_OPTIMIZED_PATH - indicates that the state is in the
-     * optimized solution path which is computed by the optimization scan.
-     *
-     * FCS_VISITED_DEAD_END - indicates that the state does not lead to
-     * anywhere useful, and scans should not examine it in the first place.
-     *
-     * FCS_VISITED_GENERATED_BY_PRUNING - indicates that the state was
-     * generated by pruning, so one can skip calling the pruning function
-     * for it.
-     * */
+    // This field contains global, scan-independant flags, which are used
+    // from the FCS_VISITED_* enum below.
+    //
+    // FCS_VISITED_IN_SOLUTION_PATH - indicates that the state is in the
+    // solution path found by the scan. (used by the optimization scan)
+    //
+    // FCS_VISITED_IN_OPTIMIZED_PATH - indicates that the state is in the
+    // optimized solution path which is computed by the optimization scan.
+    //
+    // FCS_VISITED_DEAD_END - indicates that the state does not lead to
+    // anywhere useful, and scans should not examine it in the first place.
+    //
+    // FCS_VISITED_GENERATED_BY_PRUNING - indicates that the state was
+    // generated by pruning, so one can skip calling the pruning function
+    // for it.
     fcs_game_limit visited;
 
-    /*
-     * This is a vector of flags - one for each scan. Each indicates whether
-     * its scan has already visited this state
-     * */
+    // This is a vector of flags - one for each scan. Each indicates whether
+    // its scan has already visited this state
     unsigned char scan_visited[FCS_MAX_NUM_SCANS_BUCKETS];
 
 #ifdef INDIRECT_STACK_STATES
-    /*
-     * A vector of flags that indicates which columns were already copied.
-     * */
+    // A vector of flags that indicates which columns were already copied.
     int stacks_copy_on_write_flags;
 #endif
 };
 
 typedef struct
 {
-    /*
-     * These contain the location of the original columns and freecells
-     * in the permutation of them. They are sorted by the canonization
-     * function.
-     * */
+    // These contain the location of the original columns and freecells
+    // in the permutation of them. They are sorted by the canonization
+    // function.
     fcs_locs_type stack_locs[MAX_NUM_STACKS];
 #if MAX_NUM_FREECELLS > 0
     fcs_locs_type fc_locs[MAX_NUM_FREECELLS];
@@ -333,7 +310,7 @@ static inline fcs_kv_state FCS_STATE_keyval_pair_to_kv(
     return (const fcs_kv_state){.key = &(s->s), .val = &(s->info)};
 }
 
-/* Always the same. */
+// Always the same.
 #define fcs_duplicate_kv_state(ptr_dest, ptr_src)                              \
     {                                                                          \
         *((ptr_dest)->key) = *((ptr_src)->key);                                \
@@ -398,7 +375,7 @@ static inline void FCS_STATE_collectible_to_kv(
 #define FCS_S_MOVES_TO_PARENT(s) FCS_S_ACCESSOR(s, moves_to_parent)
 #define FCS_S_VISITED(s) FCS_S_ACCESSOR(s, visited)
 #define FCS_S_SCAN_VISITED(s) FCS_S_ACCESSOR(s, scan_visited)
-#ifndef FCS_WITHOUT_DEPTH_FIELD
+#ifdef FCS_WITH_DEPTH_FIELD
 #define FCS_S_DEPTH(s) FCS_S_ACCESSOR(s, depth)
 #endif
 #ifndef FCS_WITHOUT_VISITED_ITER
@@ -465,10 +442,7 @@ extern int fc_solve_state_compare_equal(const void *, const void *);
 extern int fc_solve_state_compare_with_context(
     const void *, const void *, fcs_compare_context);
 
-/*
- * Convert an entire card to its user representation.
- *
- * */
+// Convert an entire card to its user representation.
 extern void fc_solve_card_stringify(
     const fcs_card card, char *const str PASS_T(const bool t));
 
@@ -478,13 +452,10 @@ extern void fc_solve_card_stringify(
 #define FC_SOLVE_MAP_CHAR(c) (toupper(c))
 #endif
 
-/*
- * This function converts a string containing a suit letter (that is
- * one of H,S,D,C) into its suit ID.
- *
- * The suit letter may come somewhat after the beginning of the string.
- *
- * */
+// This function converts a string containing a suit letter (that is
+// one of H,S,D,C) into its suit ID.
+//
+// The suit letter may come somewhat after the beginning of the string.
 static inline __attribute__((pure)) fcs_card fcs_str2suit(const char *suit)
 {
     while (true)
@@ -507,12 +478,8 @@ static inline __attribute__((pure)) fcs_card fcs_str2suit(const char *suit)
     }
 }
 
-/*
- * This function converts a card number from its user representation
- * (e.g: "A", "K", "9") to its card number that can be used by
- * the program.
- * */
-
+// This function converts a card number from its user representation
+// (e.g: "A", "K", "9") to its card number that can be used by the program.
 static inline __attribute__((pure)) fcs_card fcs_str2rank(const char *string)
 {
     while (1)
@@ -563,10 +530,8 @@ static inline __attribute__((pure)) fcs_card fcs_str2rank(const char *string)
         }
     }
 }
-/*
- * This function converts an entire card from its string representations
- * (e.g: "AH", "KS", "8D"), to a fcs_card data type.
- * */
+// This function converts an entire card from its string representations
+// (e.g: "AH", "KS", "8D"), to a fcs_card data type.
 static inline __attribute__((pure)) fcs_card fc_solve_card_parse_str(
     const char *const str)
 {
@@ -602,7 +567,7 @@ static inline void fc_solve_state_init_proto(fcs_state_keyval_pair *const state
 #ifdef FCS_WITH_MOVES
     state->info.moves_to_parent = NULL;
 #endif
-#ifndef FCS_WITHOUT_DEPTH_FIELD
+#ifdef FCS_WITH_DEPTH_FIELD
     state->info.depth = 0;
 #endif
     state->info.visited = 0;
@@ -664,7 +629,7 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
     bool first_line = true;
 
 #define out (out_state->s)
-/* Handle the end of string - shouldn't happen */
+// Handle the end of string - shouldn't happen
 #ifdef FCS_BREAK_BACKWARD_COMPAT_2
 #define HANDLE_EOS()                                                           \
     {                                                                          \
@@ -686,7 +651,7 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
     size_t s;
     for (s = 0; s < STACKS_NUM__VAL; ++s)
     {
-        /* Move to the next stack */
+        // Move to the next stack
         if (!first_line)
         {
             while ((*str) != '\n')
@@ -775,8 +740,8 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
                 ++str;
                 while (*str == '-')
                     ++str;
-                /* Workaround for fcs_str2rank's willingness
-                 * to designate the string '0' as 10. */
+                // Workaround for fcs_str2rank's willingness to designate the
+                // string '0' as 10.
                 const int c = ((str[0] == '0') ? 0 : fcs_str2rank(str));
                 while ((*str != ' ') && (*str != '\t') && (*str != '\n') &&
                        (*str != '\r'))
@@ -795,17 +760,17 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
             continue;
         }
 
-        /* Handle columns that start with an initial colon, so we can
-         * input states from -p -t mid-play. */
+        // Handle columns that start with an initial colon, so we can input
+        // states from -p -t mid-play.
         if ((*str) == ':')
         {
             ++str;
         }
 
         var_AUTO(col, fcs_state_get_col(out, s));
-        for (int c = 0; c < MAX_NUM_CARDS_IN_A_STACK; c++)
+        for (int c = 0; c < MAX_NUM_CARDS_IN_A_STACK; ++c)
         {
-            /* Move to the next card */
+            // Move to the next card
             if (c != 0)
             {
                 while (((*str) != ' ') && ((*str) != '\t') &&
@@ -876,7 +841,6 @@ static inline state_validity_ret fc_solve_check_state_validity(
 
     const fcs_state *const state = &(state_pair->s);
 
-    /* Initialize all card_counts to 0 */
     for (int suit_idx = 0; suit_idx < FCS_NUM_SUITS; suit_idx++)
     {
         for (int c = 1; c <= FCS_MAX_RANK; c++)
@@ -885,8 +849,8 @@ static inline state_validity_ret fc_solve_check_state_validity(
         }
     }
 
-    /* Mark the card_counts in the decks */
-    for (size_t suit_idx = 0; suit_idx < (DECKS_NUM__VAL << 2); suit_idx++)
+    // Mark the card_counts in the decks
+    for (size_t suit_idx = 0; suit_idx < (DECKS_NUM__VAL << 2); ++suit_idx)
     {
         for (int c = 1; c <= fcs_foundation_value(*state, suit_idx); c++)
         {
@@ -896,7 +860,7 @@ static inline state_validity_ret fc_solve_check_state_validity(
 
 #if MAX_NUM_FREECELLS > 0
     // Mark the card_counts in the freecells
-    for (size_t f = 0; f < FREECELLS_NUM__VAL; f++)
+    for (size_t f = 0; f < FREECELLS_NUM__VAL; ++f)
     {
         const fcs_card card = fcs_freecell_card(*state, f);
         if (fcs_card_is_valid(card))
@@ -906,8 +870,8 @@ static inline state_validity_ret fc_solve_check_state_validity(
     }
 #endif
 
-    /* Mark the card_counts in the columns */
-    for (size_t s = 0; s < STACKS_NUM__VAL; s++)
+    // Mark the card_counts in the columns
+    for (size_t s = 0; s < STACKS_NUM__VAL; ++s)
     {
         const_AUTO(col, fcs_state_get_col(*state, s));
         const int col_len = fcs_col_len(col);
@@ -919,12 +883,11 @@ static inline state_validity_ret fc_solve_check_state_validity(
                 *misplaced_card = fc_solve_empty_card;
                 return FCS_STATE_VALIDITY__EMPTY_SLOT;
             }
-            card_counts[fcs_card_suit(card)][fcs_card_rank(card)]++;
+            ++card_counts[fcs_card_suit(card)][fcs_card_rank(card)];
         }
     }
 
-    /* Now check if there are extra or missing card_counts */
-
+    // Now check if there are extra or missing card_counts
     for (size_t suit_idx = 0; suit_idx < FCS_NUM_SUITS; suit_idx++)
     {
         for (size_t rank = 1; rank <= FCS_MAX_RANK; rank++)
@@ -976,12 +939,6 @@ static inline int fc_solve_stack_compare_for_comparison(
         using std::min;
 #endif
         const int min_len = min(s1[0], s2[0]);
-#ifdef DO_NOT_ENABLE__FALSE_RESULTS
-        if (min_len)
-        {
-            return fc_solve_card_compare(s1[1], s2[1]);
-        }
-#else
         for (int a = 1; a <= min_len; a++)
         {
             const int ret = fc_solve_card_compare(s1[a], s2[a]);
@@ -990,15 +947,12 @@ static inline int fc_solve_stack_compare_for_comparison(
                 return ret;
             }
         }
-#endif
     }
-    /*
-     * The reason I do the stack length comparisons after the card-by-card
-     * comparison is to maintain correspondence with
-     * fcs_stack_compare_for_stack_sort, and with the one card comparison
-     * of the other state representation mechanisms.
-     * */
-    /* For some reason this code is faster than s1[0]-s2[0] */
+    // The reason I do the stack length comparisons after the card-by-card
+    // comparison is to maintain correspondence with
+    // fcs_stack_compare_for_stack_sort, and with the one card comparison
+    // of the other state representation mechanisms.
+    // For some reason this code is faster than s1[0]-s2[0] */
     if (s1[0] < s2[0])
     {
         return -1;
@@ -1029,13 +983,12 @@ static inline int fc_solve_stack_compare_for_canonize(
             return fc_solve_card_compare(s1[1], s2[1]);
         }
     }
-    /*
-     * The reason I do the stack length comparisons after the card-by-card
-     * comparison is to maintain correspondence with
-     * fcs_stack_compare_for_stack_sort, and with the one card comparison
-     * of the other state representation mechanisms.
-     * */
-    /* For some reason this code is faster than s1[0]-s2[0] */
+    // The reason I do the stack length comparisons after the card-by-card
+    // comparison is to maintain correspondence with
+    // fcs_stack_compare_for_stack_sort, and with the one card comparison
+    // of the other state representation mechanisms.
+
+    // For some reason this code is faster than s1[0]-s2[0]
     if (s1[0] < s2[0])
     {
         return -1;
@@ -1058,13 +1011,10 @@ static inline void set_scan_visited(
         (1 << ((scan_id) & ((1 << (FCS_CHAR_BIT_SIZE_LOG2)) - 1)));
 }
 
-/*
- * This macro determines if child can be placed above parent.
- *
- * The variable sequences_are_built_by has to be initialized to
- * the sequences_are_built_by member of the instance.
- *
- * */
+// This macro determines if child can be placed above parent.
+//
+// The variable sequences_are_built_by has to be initialized to
+// the sequences_are_built_by member of the instance.
 
 #ifdef FCS_FREECELL_ONLY
 
@@ -1074,6 +1024,7 @@ static inline bool fcs_is_parent_card(
 {
     return fc_solve_is_parent_buf[(size_t)parent][(size_t)child];
 }
+#define FCS__SEQS_ARE_BUILT_BY_RANK() false
 
 #else
 
@@ -1091,6 +1042,9 @@ static inline bool fcs_is_parent_card__helper(const fcs_card child,
 #define fcs_is_parent_card(child, parent)                                      \
     fcs_is_parent_card__helper(child, parent, sequences_are_built_by)
 
+#define FCS__SEQS_ARE_BUILT_BY_RANK()                                          \
+    (sequences_are_built_by == FCS_SEQ_BUILT_BY_RANK)
+
 #endif
 
 #define FCS_STATE__DUP_keyval_pair(dest, src)                                  \
@@ -1133,10 +1087,3 @@ static inline void fcs_state_push(
     var_AUTO(col, fcs_state_get_col(*state, col_idx));
     fcs_col_push_card(col, card);
 }
-
-#ifdef FCS_FREECELL_ONLY
-#define FCS__SEQS_ARE_BUILT_BY_RANK() false
-#else
-#define FCS__SEQS_ARE_BUILT_BY_RANK()                                          \
-    (sequences_are_built_by == FCS_SEQ_BUILT_BY_RANK)
-#endif
