@@ -5,11 +5,8 @@
 // or distributed except according to the terms contained in the COPYING file.
 //
 // Copyright (c) 2011 Shlomi Fish
-
-/*
- * A test for the DBM kaztree compare records.
- */
-#include "fcs_cmocka.h"
+// A test for the DBM kaztree compare records.
+#include "rinutils/rin_cmocka.h"
 
 #ifndef FCS_COMPILE_DEBUG_FUNCTIONS
 #define FCS_COMPILE_DEBUG_FUNCTIONS
@@ -59,8 +56,7 @@ static void main_tests(void **state GCC_UNUSED)
             }
         }
 
-        /* TEST
-         * */
+        // TEST
         assert_true(all_good); // "All compare_records were successful.");
     }
 }
