@@ -16,8 +16,12 @@ sub _build_argv
 }
 
 has input_argv => ( is => 'ro', isa => 'ArrayRef[Str]', required => 1, );
-has argv =>
-    ( is => 'ro', isa => 'ArrayRef[Str]', lazy => 1, default => \&_build_argv );
+has argv       => (
+    is      => 'ro',
+    isa     => 'ArrayRef[Str]',
+    lazy    => 1,
+    default => \&_build_argv
+);
 
 sub _process_cmd_line
 {
@@ -62,7 +66,7 @@ sub _process_cmd_line
         {
             ++$idx;
             my $preset_name = $argv[$idx];
-            open my $in, '<', "$ENV{FCS_PATH}/Presets/presetrc"
+            open my $in, '<', "$ENV{FCS_BIN_PATH}/Presets/presetrc"
                 or die "Cannot open presetrc file - $!";
             my $cmd_found;
         PRESETRC:
